#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIGN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIGN_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/sign.hpp>

#endif
